import QtQuick 2.0
import Ubuntu.Components 0.1



/*!
    \brief MainView with Tabs element.
           First Tab has a single Label and
           second Tab has a single ToolbarAction.
*/

import "databasemodule.js" as DB

MainView {
    // objectName for functional testing purposes (autopilot-qt5)
    objectName: "rssreader"
    applicationName: "ubuntu-rssreader-app"
    
    width: units.gu(50)
    height: units.gu(75)

    PageStack {
        id: mainPageStack
        Component.onCompleted: {
            push(todayPage)
            todayPage.refresh()
        }
        anchors.fill: parent
        __showHeader: false
        TodayPage {
            id: todayPage
            visible: false
            onRequestFeedListPage: mainPageStack.push(feedListPage)
        }

        FeedListPage {
            id: feedListPage
            visible: false
            anchors.fill: parent
            onFeedSelected: {
                if(selectedFeed != "") {
                    mainPageStack.push(selectedEntryListPageView)
                    selectedEntryListPage.feedLink = selectedFeed
                    var feed = DB.loadFeed(selectedFeed)
                    selectedEntryTab.title = feed.displayName
                } else {
                    mainPageStack.clear()
                    mainPageStack.push(todayPage)
                }
            }
            onFeedsReloaded: {
                todayPage.refresh()
            }
            onFeedDeleted: {
                todayPage.refresh()
            }
        }
        Page {
            anchors.fill: parent
            id: selectedEntryListPageView
            visible: false
            Tabs {
                anchors.fill: parent
                Tab {
                    id: selectedEntryTab
                    title: i18n.tr("Selected feed") // todo replace with feed name
                    page: EntryListPage {
                        anchors.fill: parent
                        id: selectedEntryListPage
                    }
                }
            }
        }
        SingleEntryPage {
            id: singleEntryPage
            visible: false
            anchors.fill: parent
        }
    }
}
